@@ -3,7 +3,7 @@
 ;; Copyright (C) 2020  Free Software Foundation, Inc.
 
 ;; Author: Philip K. <philipk@posteo.net>
-;; Version: 1.0.3
+;; Version: 2.0.0
 ;; Keywords: unix, processes, convenience
 ;; Package-Requires: ((emacs "24.1"))
 ;; URL: http://elpa.gnu.org/packages/shell-command+.html
@@ -24,7 +24,10 @@
 ;;; Commentary:
 ;;
 ;; `shell-command+' is a `shell-command' substitute, that extends the
-;; regular Emacs command with several features.
+;; regular Emacs command with several features.  After installed,
+;; configure the package as follows:
+;;
+;;	(global-set-key (kbd "M-!") #'shell-command+)
 ;;
 ;; A few examples of what `shell-command+' can do:
 ;;
@@ -49,8 +52,11 @@
 ;;
 ;;	... make
 ;;
-;; Run Eshell's make (i.e. `compile') in the parent's parent
+;; Run Eshell's make (via `compile') in the parent's parent
 ;; directory.
+;;
+;; See `shell-command+'s docstring for more details on how it's input
+;; is interpreted..
 
 (eval-when-compile (require 'rx))
 (require 'eshell)
@@ -63,8 +69,11 @@
   :prefix "shell-command+-")
 
 (defcustom shell-command+-use-eshell t
-  "Check if there is an eshell-handler for each command."
-  :type 'boolean)
+  "Check for eshell handlers.
+If t, always invoke eshell handlers.  If a list, only invoke
+handlers if the symbol (eg. `man') is contained in the list."
+  :type '(choice (boolean :tag "Always active?")
+                 (repeat :tag "Selected commands" symbol)))
 
 (defconst shell-command+--command-regexp
   (rx bos
@@ -79,8 +88,8 @@
       ;; allow whitespace after indicator
       (* space)
       ;; actual command (and command name)
-      (group (: (group (*? not-newline))
-                (? space))
+      (group (? (group (+ not-newline))
+                (+ space))
              (+ not-newline))
       eos)
   "Regular expression to parse `shell-command+' input.")
@@ -149,7 +158,8 @@ between BEG and END.  Otherwise the whole buffer is processed."
                (shell-command-on-region
                 beg end rest t t
                 shell-command-default-error-buffer t))
-              ((and shell-command+-use-eshell
+              ((and (or (eq shell-command+-use-eshell t)
+                        (memq (intern cmd) shell-command+-use-eshell))
                     (intern-soft (concat "eshell/" cmd)))
                (eshell-command rest (and current-prefix-arg t)))
               (t (shell-command rest (and current-prefix-arg t)
